<header class="align-items-center d-flex flex-row gap-2 mb-3 p-3">
    <img alt="Coventry University Logo" src="{{ 'images/logo.svg' | url }}"
         style="width: 15rem"/>
    <div class="d-flex flex-column flex-grow-1 gap-1">
        <div class="d-flex flex-row flex-grow gap-1">
            <h1 class="fs-4 m-0">{{ config.module.code }}</h1>
            <h1 class="fs-4 m-0">{{ config.module.title }}</h1>
        </div>
        <h2 class="fs-6 fst-italic fw-light m-0 text-white">{{ page.title }}</h2>
    </div>
</header>