.nav-link-custom {
    display: flex;
    align-items: center;
    padding: 0.625rem 1rem;
    color: #495057;
    text-decoration: none;
    border-radius: 0.5rem;
    transition: all 0.2s ease;
    font-weight: 500;
}

.nav-link-custom:hover {
    background-color: #e9ecef;
    color: #667eea;
}