html, body {
    background-color: rgba(43, 48, 53, 0.0575) !important;
}

html, body {
    font-family: "Ubuntu Sans", serif;
}

pre, code {
    font-family: "Ubuntu Mono", sans-serif;
}

.accent-color {
    color: #256cba;
}

.task-bullet {
    background: linear-gradient(135deg, #256CBA 0%, #AEB7BF 100%);
}

.border-left-accent {
    border-left: 2px solid #256cba;
}

.table-hover > tbody > tr:hover > * {
    background-color: #FEFEFE !important;
}