header {
    background: linear-gradient(135deg, #256CBA 0%, #AEB7BF 100%);
    border-radius: 1rem;
    box-shadow: 0 0.125rem 0.25rem rgba(0, 0, 0, 0.075);
    display: flex;
    flex-direction: row;
    gap: 1rem;
    padding: 1rem;
}