.btn-blue {
    background-color: #256CBA !important;
    color: white !important;
}

.btn-blue:hover {
    background-color: #256CBACC !important;
}

.btn-none {
    border: unset !important;
    color: black !important;
}

.carousel-control-prev-icon {
    background-image: url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 16 16' fill='%23000'%3e%3cpath d='M11.354 1.646a.5.5 0 0 1 0 .708L5.707 8l5.647 5.646a.5.5 0 0 1-.708.708l-6-6a.5.5 0 0 1 0-.708l6-6a.5.5 0 0 1 .708 0'/%3e%3c/svg%3e");
}

.carousel-control-prev-next {
    background-image: url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 16 16' fill='%23000'%3e%3cpath d='M11.354 1.646a.5.5 0 0 1 0 .708L5.707 8l5.647 5.646a.5.5 0 0 1-.708.708l-6-6a.5.5 0 0 1 0-.708l6-6a.5.5 0 0 1 .708 0'/%3e%3c/svg%3e");
}

.bg-header-gradient, .bg-input-gradient {
    background: linear-gradient(135deg, #256CBA 0%, #AEB7BF 100%);
    /*background: linear-gradient(135deg, #667eea 0%, #764ba2 100%);*/
}

.shadow {
    box-shadow: 0 0.5rem 1.5rem rgba(0, 0, 0, 0.08) !important;
}

.btn {
    border: unset !important;
}

.btn-link {
    background: linear-gradient(135deg, #256CBA 0%, #AEB7BF 100%);
    border: none;
    color: white;
    font-weight: 600;
    padding: 0.75rem 1rem;
    border-radius: 0.75rem;
    transition: all 0.3s ease;
}

.btn-link:not(.collapsed) {
    background: linear-gradient(135deg, #AEB7BF 0%, #256CBA 100%);
    border-bottom-left-radius: 0;
    border-bottom-right-radius: 0;
}