h1, h2, h3, h4 {
    -webkit-background-clip: text;
    -webkit-text-fill-color: transparent;
    background: linear-gradient(135deg, #256CBA 0%, #AEB7BF 150%);
    background-clip: text !important;
    width: fit-content;
}

h1 {
    font-size: xx-large;
    font-weight: bolder;
}

h2 {
    font-size: x-large;
    font-weight: bold;
}

h3 {
    font-size: large;
    font-weight: bold;
}

h4 {
    font-size: medium;
    font-weight: bold;
}

header > div > div > h1,
header > div > h2 {
    -webkit-text-fill-color: unset;
    background: unset;
    background-clip: unset;
    color: white;
}