.tabbed-set {
    align-items: start;
    justify-content: start;
    position: relative;
    display: flex;
    flex-wrap: wrap;
    border-radius: 0.1rem;
}

.tabbed-set > input {
    display: none;
}

.tabbed-set label {

    -webkit-background-clip: text;
    -webkit-text-fill-color: transparent;
    background: linear-gradient(135deg, #256CBA 0%, #AEB7BF 150%);
    background-clip: text !important;
    width: fit-content;

    padding: 0.65rem 1.25rem;
    font-weight: 550;
    font-size: 1rem;
    white-space: nowrap;
    border-bottom-width: calc(var(--bs-border-width) * 2);
    border-left-width: 0;
    border-right-width: 0;
    border-top-width: 0;
    border-color: var(--bs-border-color);
    border-style: var(--bs-border-style);
    cursor: pointer;
    margin-right: 0.5rem;
    transition: background-color 250ms, color 250ms;
}

.tabbed-set .tabbed-content {
    width: 100%;
    display: none;
}

.tabbed-set input {
    position: absolute;
    opacity: 0;
}

.tabbed-set {
    margin-bottom: 0.75rem;
}

.tabbed-set:last-child {
    margin-bottom: 0;
}

.tabbed-set input:checked:nth-child(n+1) + label {
    position: relative;
    border: unset;
}

.tabbed-set input:checked:nth-child(n+1) + label::after {
    content: '';
    position: absolute;
    bottom: 0;
    left: 0;
    right: 0;
    height: var(--bs-border-width);
    background: linear-gradient(135deg, #256CBA 0%, #AEB7BF 80%);
}

.tabbed-set input:checked:nth-child(n+1) + label + .tabbed-content {
    padding: 0.5rem;
}

.tabbed-content > p {
    margin: 0 0 0 0;
}

.tabbed-content p:has(a.glightbox) {
    display: none;
}

[class*=download-]:before {
    content: "\F356";
    font-family: "bootstrap-icons";
    margin-right: 0.5rem;
    padding: 0;
}

p:has(a[class*='download-']) {
    align-items: center;
    display: flex;
    justify-content: center;
}

[class*=download-] {
    display: block;
    background: rgba(var(--bs-body-color-rgb), 0.03);
    border-color: var(--bs-border-color-translucent);
    border-radius: var(--bs-border-radius-lg);
    border-style: var(--bs-border-style);
    border-width: var(--bs-border-width);
    line-height: 1rem;
    margin-top: 0.75rem;
    margin-right: 0.5rem;
    padding: 0.75rem;
    text-align: center;
    width: 25vw;
}


@media screen {
    .tabbed-set input:nth-child(n+1):checked + label + .tabbed-content {
        order: 99;
        display: block;
    }
}

@media print {
    .tabbed-content {
        display: contents;
    }
}